==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ki-KE.pl <==
{
  am_pm_abbreviated => [
    "Kiroko",
    "Hwa\N{U+0129}-in\N{U+0129}"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ki-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "NTT",
    "NMN",
    "NMT",
    "ART",
    "NMA",
    "NMM",
    "KMA"
  ],
  day_format_narrow => [
    "N",
    "N",
    "N",
    "A",
    "N",
    "N",
    "K"
  ],
  day_format_wide => [
    "Njumatat\N{U+0169}",
    "Njumaine",
    "Njumatana",
    "Aramithi",
    "Njumaa",
    "Njumamothi",
    "Kiumia"
  ],
  day_stand_alone_abbreviated => [
    "NTT",
    "NMN",
    "NMT",
    "ART",
    "NMA",
    "NMM",
    "KMA"
  ],
  day_stand_alone_narrow => [
    "N",
    "N",
    "N",
    "A",
    "N",
    "N",
    "K"
  ],
  day_stand_alone_wide => [
    "Njumatat\N{U+0169}",
    "Njumaine",
    "Njumatana",
    "Aramithi",
    "Njumaa",
    "Njumamothi",
    "Kiumia"
  ],
  era_abbreviated => [
    "MK",
    "TK"
  ],
  era_narrow => [
    "MK",
    "TK"
  ],
  era_wide => [
    "Mbere ya Kristo",
    "Thutha wa Kristo"
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kikuyu",
  month_format_abbreviated => [
    "JEN",
    "WKR",
    "WGT",
    "WKN",
    "WTN",
    "WTD",
    "WMJ",
    "WNN",
    "WKD",
    "WIK",
    "WMW",
    "DIT"
  ],
  month_format_narrow => [
    "J",
    "K",
    "G",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "D"
  ],
  month_format_wide => [
    "Njenuar\N{U+0129}",
    "Mwere wa ker\N{U+0129}",
    "Mwere wa gatat\N{U+0169}",
    "Mwere wa kana",
    "Mwere wa gatano",
    "Mwere wa gatandat\N{U+0169}",
    "Mwere wa m\N{U+0169}gwanja",
    "Mwere wa kanana",
    "Mwere wa kenda",
    "Mwere wa ik\N{U+0169}mi",
    "Mwere wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Ndithemba"
  ],
  month_stand_alone_abbreviated => [
    "JEN",
    "WKR",
    "WGT",
    "WKN",
    "WTN",
    "WTD",
    "WMJ",
    "WNN",
    "WKD",
    "WIK",
    "WMW",
    "DIT"
  ],
  month_stand_alone_narrow => [
    "J",
    "K",
    "G",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "D"
  ],
  month_stand_alone_wide => [
    "Njenuar\N{U+0129}",
    "Mwere wa ker\N{U+0129}",
    "Mwere wa gatat\N{U+0169}",
    "Mwere wa kana",
    "Mwere wa gatano",
    "Mwere wa gatandat\N{U+0169}",
    "Mwere wa m\N{U+0169}gwanja",
    "Mwere wa kanana",
    "Mwere wa kenda",
    "Mwere wa ik\N{U+0169}mi",
    "Mwere wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Ndithemba"
  ],
  name => "Kikuyu Kenya",
  native_language => "Gikuyu",
  native_name => "Gikuyu Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Robo ya mbere",
    "Robo ya ker\N{U+0129}",
    "Robo ya gatat\N{U+0169}",
    "Robo ya kana"
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Robo ya mbere",
    "Robo ya ker\N{U+0129}",
    "Robo ya gatat\N{U+0169}",
    "Robo ya kana"
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.22.tar.gz: DateTime-Locale-1.22/share/ki-KE.pl <==
{
  am_pm_abbreviated => [
    "Kiroko",
    "Hwa\N{U+0129}-in\N{U+0129}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ki-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "NTT",
    "NMN",
    "NMT",
    "ART",
    "NMA",
    "NMM",
    "KMA",
  ],
  day_format_narrow => [
    "N",
    "N",
    "N",
    "A",
    "N",
    "N",
    "K",
  ],
  day_format_wide => [
    "Njumatat\N{U+0169}",
    "Njumaine",
    "Njumatana",
    "Aramithi",
    "Njumaa",
    "Njumamothi",
    "Kiumia",
  ],
  day_stand_alone_abbreviated => [
    "NTT",
    "NMN",
    "NMT",
    "ART",
    "NMA",
    "NMM",
    "KMA",
  ],
  day_stand_alone_narrow => [
    "N",
    "N",
    "N",
    "A",
    "N",
    "N",
    "K",
  ],
  day_stand_alone_wide => [
    "Njumatat\N{U+0169}",
    "Njumaine",
    "Njumatana",
    "Aramithi",
    "Njumaa",
    "Njumamothi",
    "Kiumia",
  ],
  era_abbreviated => [
    "MK",
    "TK",
  ],
  era_narrow => [
    "MK",
    "TK",
  ],
  era_wide => [
    "Mbere ya Kristo",
    "Thutha wa Kristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kikuyu",
  month_format_abbreviated => [
    "JEN",
    "WKR",
    "WGT",
    "WKN",
    "WTN",
    "WTD",
    "WMJ",
    "WNN",
    "WKD",
    "WIK",
    "WMW",
    "DIT",
  ],
  month_format_narrow => [
    "J",
    "K",
    "G",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "D",
  ],
  month_format_wide => [
    "Njenuar\N{U+0129}",
    "Mwere wa ker\N{U+0129}",
    "Mwere wa gatat\N{U+0169}",
    "Mwere wa kana",
    "Mwere wa gatano",
    "Mwere wa gatandat\N{U+0169}",
    "Mwere wa m\N{U+0169}gwanja",
    "Mwere wa kanana",
    "Mwere wa kenda",
    "Mwere wa ik\N{U+0169}mi",
    "Mwere wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Ndithemba",
  ],
  month_stand_alone_abbreviated => [
    "JEN",
    "WKR",
    "WGT",
    "WKN",
    "WTN",
    "WTD",
    "WMJ",
    "WNN",
    "WKD",
    "WIK",
    "WMW",
    "DIT",
  ],
  month_stand_alone_narrow => [
    "J",
    "K",
    "G",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "D",
  ],
  month_stand_alone_wide => [
    "Njenuar\N{U+0129}",
    "Mwere wa ker\N{U+0129}",
    "Mwere wa gatat\N{U+0169}",
    "Mwere wa kana",
    "Mwere wa gatano",
    "Mwere wa gatandat\N{U+0169}",
    "Mwere wa m\N{U+0169}gwanja",
    "Mwere wa kanana",
    "Mwere wa kenda",
    "Mwere wa ik\N{U+0169}mi",
    "Mwere wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Ndithemba",
  ],
  name => "Kikuyu Kenya",
  native_language => "Gikuyu",
  native_name => "Gikuyu Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Robo ya mbere",
    "Robo ya ker\N{U+0129}",
    "Robo ya gatat\N{U+0169}",
    "Robo ya kana",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Robo ya mbere",
    "Robo ya ker\N{U+0129}",
    "Robo ya gatat\N{U+0169}",
    "Robo ya kana",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}
